==> mars-0.9.2.tar.gz: mars-0.9.2/include/host/mars/mars_workload_queue.h <==
/*
 * Copyright 2008 Sony Corporation of America
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this Library and associated documentation files (the
 * "Library"), to deal in the Library without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Library, and to
 * permit persons to whom the Library is furnished to do so, subject to
 * the following conditions:
 *
 *  The above copyright notice and this permission notice shall be
 *  included in all copies or substantial portions of the Library.
 *
 *  If you modify the Library, you may copy and distribute your modified
 *  version of the Library in object code or as an executable provided
 *  that you also do one of the following:
 *
 *   Accompany the modified version of the Library with the complete
 *   corresponding machine-readable source code for the modified version
 *   of the Library; or,
 *
 *   Accompany the modified version of the Library with a written offer
 *   for a complete machine-readable copy of the corresponding source
 *   code of the modified version of the Library.
 *
 *
 * THE LIBRARY IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * LIBRARY OR THE USE OR OTHER DEALINGS IN THE LIBRARY.
 */

#ifndef MARS_WORKLOAD_QUEUE_H
#define MARS_WORKLOAD_QUEUE_H

#if defined(__cplusplus)
extern "C" {
#endif

#include "mars/mars_workload_types.h"

int workload_queue_initialize(struct mars_workload_queue *queue);
int workload_queue_finalize(struct mars_workload_queue *queue);

int workload_queue_add_begin(struct mars_workload_queue *queue, uint16_t *id,
				uint8_t type,
				struct mars_workload_context **workload);
int workload_queue_add_end(struct mars_workload_queue *queue, uint16_t id);
int workload_queue_add_cancel(struct mars_workload_queue *queue, uint16_t id);

int workload_queue_remove_begin(struct mars_workload_queue *queue, uint16_t id,
				struct mars_workload_context **workload);
int workload_queue_remove_end(struct mars_workload_queue *queue, uint16_t id);
int workload_queue_remove_cancel(struct mars_workload_queue *queue,
				uint16_t id);

int workload_queue_schedule_begin(struct mars_workload_queue *queue,
				uint16_t id, uint8_t priority,
				struct mars_workload_context **workload);
int workload_queue_schedule_end(struct mars_workload_queue *queue, uint16_t id);
int workload_queue_schedule_cancel(struct mars_workload_queue *queue,
				uint16_t id);

int workload_queue_wait(struct mars_workload_queue *queue, uint16_t id,
			struct mars_workload_context **workload);
int workload_queue_try_wait(struct mars_workload_queue *queue, uint16_t id,
			struct mars_workload_context **workload);
int workload_queue_signal_send(struct mars_workload_queue *queue, uint16_t id);

#if defined(__cplusplus)
}
#endif

#endif

==> mars-08.06.26.tar.gz: mars-08.06.26/include/host/mars/mars_workload_queue.h <==
/*
 * Copyright 2008 Sony Corporation of America
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this Library and associated documentation files (the
 * "Library"), to deal in the Library without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Library, and to
 * permit persons to whom the Library is furnished to do so, subject to
 * the following conditions:
 *
 *  The above copyright notice and this permission notice shall be 
 *  included in all copies or substantial portions of the Library.
 *
 *  If you modify the Library, you may copy and distribute your modified 
 *  version of the Library in object code or as an executable provided 
 *  that you also do one of the following:
 *
 *   Accompany the modified version of the Library with the complete 
 *   corresponding machine-readable source code for the modified version 
 *   of the Library; or,
 *
 *   Accompany the modified version of the Library with a written offer 
 *   for a complete machine-readable copy of the corresponding source 
 *   code of the modified version of the Library.
 *
 *
 * THE LIBRARY IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 * CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 * LIBRARY OR THE USE OR OTHER DEALINGS IN THE LIBRARY.
 */

#ifndef MARS_WORKLOAD_QUEUE_H
#define MARS_WORKLOAD_QUEUE_H

#if defined(__cplusplus)
extern "C" {
#endif

#include "mars/mars_workload_types.h"

int workload_queue_initialize(struct mars_workload_queue *queue);
int workload_queue_finalize(struct mars_workload_queue *queue);
int workload_queue_add(struct mars_workload_queue *queue, uint16_t *id,
			struct mars_workload_context *workload);
int workload_queue_remove(struct mars_workload_queue *queue, uint16_t id,
			struct mars_workload_context *workload);
int workload_queue_context(struct mars_workload_queue *queue, uint16_t id,
			struct mars_workload_context **workload);
int workload_queue_schedule(struct mars_workload_queue *queue, uint16_t id,
			uint8_t priority);
int workload_queue_wait(struct mars_workload_queue *queue, uint16_t id);
int workload_queue_try_wait(struct mars_workload_queue *queue, uint16_t id);
int workload_queue_signal_send(struct mars_workload_queue *queue, uint16_t id);

#if defined(__cplusplus)
}
#endif

#endif
